@@ -722,6 +722,7 @@ typedef enum {
 	CH_ERROR_SELF_TEST_BLUE,
 	CH_ERROR_SELF_TEST_COLOR_SELECT,
 	CH_ERROR_SELF_TEST_MULTIPLIER,
+	CH_ERROR_INVALID_CALIBRATION,
 	CH_ERROR_LAST
 } ChError;
 
@@ -729,7 +730,7 @@ typedef enum {
 typedef enum {
 	CH_PCB_ERRATA_NONE		= 0,
 	CH_PCB_ERRATA_SWAPPED_LEDS	= 1 << 0,
-	CH_PCB_ERRATA_LAST		= 1 << 1
+	CH_PCB_ERRATA_NO_WELCOME	=  1 << 1,
 } ChPcbErrata;
 
 /* prototypes */
