@@ -26,11 +26,35 @@
 #include <glib-object.h>
 #include <gusb.h>
 #include <math.h>
+#include <colord.h>
 
 #include "ch-math.h"
+#include "ch-hash.h"
 #include "ch-device.h"
 #include "ch-device-queue.h"
 
+static void
+ch_test_hash_func (void)
+{
+	ChSha1 sha1;
+	gboolean ret;
+	gchar *str;
+	GError *error = NULL;
+
+	/* parse into structure */
+	ret = ch_sha1_parse ("f18973b4ebaeab527dc15d5dd246debfbff20324",
+			     &sha1, &error);
+	g_assert_no_error (error);
+	g_assert (ret);
+	g_assert_cmpint (sha1.bytes[0], == ,241);
+	g_assert_cmpint (sha1.bytes[1], ==, 137);
+
+	/* print back to string */
+	str = ch_sha1_to_string (&sha1);
+	g_assert_cmpstr (str, ==, "f18973b4ebaeab527dc15d5dd246debfbff20324");
+	g_free (str);
+}
+
 static guint device_failed_cnt = 0;
 static guint progress_changed_cnt = 0;
 
@@ -89,7 +113,7 @@ ch_test_device_queue_func (void)
 		device = g_ptr_array_index (devices, i);
 		if (g_usb_device_get_vid (device) != CH_USB_VID)
 			continue;
-		if (g_usb_device_get_pid (device) != CH_USB_PID)
+		if (g_usb_device_get_pid (device) != CH_USB_PID_FIRMWARE)
 			continue;
 
 		valid_devices++;
@@ -159,7 +183,7 @@ ch_test_device_queue_func (void)
 		device = g_ptr_array_index (devices, i);
 		if (g_usb_device_get_vid (device) != CH_USB_VID)
 			continue;
-		if (g_usb_device_get_pid (device) != CH_USB_PID)
+		if (g_usb_device_get_pid (device) != CH_USB_PID_FIRMWARE)
 			continue;
 		ch_device_queue_add (device_queue,
 				     device,
@@ -431,7 +455,7 @@ ch_client_get_default (GError **error)
 	g_usb_device_list_coldplug (list);
 	device = g_usb_device_list_find_by_vid_pid (list,
 						    CH_USB_VID,
-						    CH_USB_PID,
+						    CH_USB_PID_FIRMWARE,
 						    error);
 	if (device == NULL)
 		goto out;
@@ -1121,6 +1145,7 @@ main (int argc, char **argv)
 	g_log_set_fatal_mask (NULL, G_LOG_LEVEL_ERROR | G_LOG_LEVEL_CRITICAL);
 
 	/* tests go here */
+	g_test_add_func ("/ColorHug/hash", ch_test_hash_func);
 	g_test_add_func ("/ColorHug/device-queue", ch_test_device_queue_func);
 	g_test_add_func ("/ColorHug/math-convert", ch_test_math_convert_func);
 	g_test_add_func ("/ColorHug/math-add", ch_test_math_add_func);
