@@ -38,7 +38,7 @@ typedef struct {
 	GUsbDevice	*device;
 	GUsbDeviceList	*device_list;
 	SoupSession	*session;
-	guint16		 calibration_map[6];
+	guint16		 calibration_map[CH_CALIBRATION_MAX];
 	guint		 ccmx_idx;
 	guint8		 ccmx_types[CH_CALIBRATION_MAX];
 	gchar		*ccmx_description[CH_CALIBRATION_MAX];
@@ -180,7 +180,7 @@ ch_ccmx_add_local_file (ChCcmxPrivate *priv,
 	gsize ccmx_size;
 	GtkListStore *list_store;
 	GtkTreeIter iter;
-	guint8 types = 0;
+	guint8 types;
 
 	/* load file */
 	g_debug ("opening %s", filename);
@@ -213,15 +213,20 @@ ch_ccmx_add_local_file (ChCcmxPrivate *priv,
 		goto out;
 	}
 
-	/* get the types */
-	if (cd_it8_has_option (it8, "TYPE_LCD"))
-		types += CH_CALIBRATION_TYPE_LCD;
-	if (cd_it8_has_option (it8, "TYPE_LED"))
-		types += CH_CALIBRATION_TYPE_LED;
-	if (cd_it8_has_option (it8, "TYPE_CRT"))
-		types += CH_CALIBRATION_TYPE_CRT;
-	if (cd_it8_has_option (it8, "TYPE_PROJECTOR"))
-		types += CH_CALIBRATION_TYPE_PROJECTOR;
+	/* get the supported display types */
+	if (cd_it8_has_option (it8, "TYPE_FACTORY")) {
+		types = CH_CALIBRATION_TYPE_ALL;
+	} else {
+		types = 0;
+		if (cd_it8_has_option (it8, "TYPE_LCD"))
+			types += CH_CALIBRATION_TYPE_LCD;
+		if (cd_it8_has_option (it8, "TYPE_LED"))
+			types += CH_CALIBRATION_TYPE_LED;
+		if (cd_it8_has_option (it8, "TYPE_CRT"))
+			types += CH_CALIBRATION_TYPE_CRT;
+		if (cd_it8_has_option (it8, "TYPE_PROJECTOR"))
+			types += CH_CALIBRATION_TYPE_PROJECTOR;
+	}
 
 	/* is suitable for LCD */
 	list_store = GTK_LIST_STORE (gtk_builder_get_object (priv->builder, "liststore_lcd"));
@@ -382,7 +387,9 @@ ch_ccmx_got_factory_calibration_cb (SoupSession *session,
 	gboolean ret;
 	gchar *location = NULL;
 	GError *error = NULL;
+	GtkListStore *list_store;
 	SoupURI *uri;
+	guint i;
 
 	/* we failed */
 	if (!SOUP_STATUS_IS_SUCCESSFUL (msg->status_code)) {
@@ -416,6 +423,21 @@ ch_ccmx_got_factory_calibration_cb (SoupSession *session,
 		g_error_free (error);
 		goto out;
 	}
+
+	/* reset the calibration map too */
+	for (i = 0; i < CH_CALIBRATION_MAX; i++)
+		priv->calibration_map[i] = 0;
+
+	/* clear any existing profiles */
+	list_store = GTK_LIST_STORE (gtk_builder_get_object (priv->builder, "liststore_lcd"));
+	gtk_list_store_clear (list_store);
+	list_store = GTK_LIST_STORE (gtk_builder_get_object (priv->builder, "liststore_led"));
+	gtk_list_store_clear (list_store);
+	list_store = GTK_LIST_STORE (gtk_builder_get_object (priv->builder, "liststore_crt"));
+	gtk_list_store_clear (list_store);
+	list_store = GTK_LIST_STORE (gtk_builder_get_object (priv->builder, "liststore_projector"));
+	gtk_list_store_clear (list_store);
+	g_hash_table_remove_all (priv->hash);
 out:
 	g_free (location);
 }
@@ -696,9 +718,6 @@ ch_ccmx_get_calibration_cb (GObject *source,
 	/* add local files */
 	ch_ccmx_add_local_files (priv);
 
-
-{
-
 	/* setup UI */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "box_progress"));
 	gtk_widget_hide (widget);
@@ -719,15 +738,14 @@ ch_ccmx_get_calibration_cb (GObject *source,
 	priv->done_get_cal = TRUE;
 
 	/* offer to repair the device */
-	if (priv->needs_repair)
+	if (priv->needs_repair) {
+		priv->force_repair = FALSE;
 		ch_ccmx_device_needs_repair (priv);
-	else if (priv->force_repair) {
+	} else if (priv->force_repair) {
 		ch_ccmx_device_force_repair (priv);
 		/* Force repair only once */
 		priv->force_repair = FALSE;
 	}
-}
-
 out:
 	return;
 }
@@ -857,7 +875,6 @@ ch_ccmx_set_calibration_data (ChCcmxPrivate *priv,
 	const CdMat3x3 *calibration;
 	const gchar *description;
 	gboolean ret = TRUE;
-	gboolean type_factory = FALSE;
 	guint8 types = 0;
 
 	/* read ccmx */
@@ -875,16 +892,20 @@ ch_ccmx_set_calibration_data (ChCcmxPrivate *priv,
 		goto out;
 	}
 
-	/* get the types */
-	type_factory = cd_it8_has_option (it8, "TYPE_FACTORY");
-	if (type_factory || cd_it8_has_option (it8, "TYPE_LCD"))
-		types += CH_CALIBRATION_TYPE_LCD;
-	if (type_factory || cd_it8_has_option (it8, "TYPE_LED"))
-		types += CH_CALIBRATION_TYPE_LED;
-	if (type_factory || cd_it8_has_option (it8, "TYPE_CRT"))
-		types += CH_CALIBRATION_TYPE_CRT;
-	if (type_factory || cd_it8_has_option (it8, "TYPE_PROJECTOR"))
-		types += CH_CALIBRATION_TYPE_PROJECTOR;
+	/* get the supported display types */
+	if (cd_it8_has_option (it8, "TYPE_FACTORY")) {
+		types = CH_CALIBRATION_TYPE_ALL;
+	} else {
+		types = 0;
+		if (cd_it8_has_option (it8, "TYPE_LCD"))
+			types += CH_CALIBRATION_TYPE_LCD;
+		if (cd_it8_has_option (it8, "TYPE_LED"))
+			types += CH_CALIBRATION_TYPE_LED;
+		if (cd_it8_has_option (it8, "TYPE_CRT"))
+			types += CH_CALIBRATION_TYPE_CRT;
+		if (cd_it8_has_option (it8, "TYPE_PROJECTOR"))
+			types += CH_CALIBRATION_TYPE_PROJECTOR;
+	}
 
 	/* set to HW */
 	calibration = cd_it8_get_matrix (it8);
@@ -1572,7 +1593,8 @@ ch_ccmx_device_added_cb (GUsbDeviceList *list,
 	g_debug ("Added: %i:%i",
 		 g_usb_device_get_vid (device),
 		 g_usb_device_get_pid (device));
-	if (ch_device_get_mode (device) == CH_DEVICE_MODE_FIRMWARE) {
+	if (ch_device_get_mode (device) == CH_DEVICE_MODE_FIRMWARE ||
+	    ch_device_get_mode (device) == CH_DEVICE_MODE_LEGACY) {
 		priv->device = g_object_ref (device);
 		ch_ccmx_got_device (priv);
 	}
@@ -1589,7 +1611,8 @@ ch_ccmx_device_removed_cb (GUsbDeviceList *list,
 	g_debug ("Removed: %i:%i",
 		 g_usb_device_get_vid (device),
 		 g_usb_device_get_pid (device));
-	if (ch_device_get_mode (device) == CH_DEVICE_MODE_FIRMWARE) {
+	if (ch_device_get_mode (device) == CH_DEVICE_MODE_FIRMWARE ||
+	    ch_device_get_mode (device) == CH_DEVICE_MODE_LEGACY) {
 		if (priv->device != NULL)
 			g_object_unref (priv->device);
 		priv->device = NULL;
