@@ -183,23 +183,27 @@ static gboolean
 ch_util_get_prompt (const gchar *question, gboolean defaultyes)
 {
 	gboolean ret = FALSE;
-	gboolean valid = FALSE;
 	gchar value;
 
 	g_print ("%s %s ",
 		 question,
 		 defaultyes ? "[Y/n]" : "[N/y]");
-	while (!valid) {
+	while (TRUE) {
 		value = getchar ();
 		if (value == 'y' || value == 'Y') {
-			valid = TRUE;
 			ret = TRUE;
+			goto out;
 		}
 		if (value == 'n' || value == 'N') {
-			valid = TRUE;
 			ret = FALSE;
+			goto out;
+		}
+		if (value == '\n') {
+			ret = defaultyes;
+			goto out;
 		}
 	}
+out:
 	return ret;
 }
 
@@ -986,6 +990,24 @@ out:
 	return ret;
 }
 
+/**
+ * ch_util_types_to_short_string:
+ **/
+static gchar *
+ch_util_types_to_short_string (guint8 types)
+{
+	GString *str = g_string_new ("");
+	if ((types & CH_CALIBRATION_TYPE_LCD) > 0)
+		g_string_append (str, "L");
+	if ((types & CH_CALIBRATION_TYPE_CRT) > 0)
+		g_string_append (str, "C");
+	if ((types & CH_CALIBRATION_TYPE_PROJECTOR) > 0)
+		g_string_append (str, "P");
+	if ((types & CH_CALIBRATION_TYPE_LED) > 0)
+		g_string_append (str, "E");
+	return g_string_free (str, FALSE);
+}
+
 /**
  * ch_util_list_calibration:
  **/
@@ -994,9 +1016,11 @@ ch_util_list_calibration (ChUtilPrivate *priv, gchar **values, GError **error)
 {
 	gboolean ret;
 	gchar description[CH_CALIBRATION_DESCRIPTION_LEN];
+	gchar *tmp;
 	GError *error_local = NULL;
 	GString *string;
 	guint16 i;
+	guint8 types;
 
 	string = g_string_new ("");
 	for (i = 0; i < CH_CALIBRATION_MAX; i++) {
@@ -1005,7 +1029,7 @@ ch_util_list_calibration (ChUtilPrivate *priv, gchar **values, GError **error)
 						 priv->device,
 						 i,
 						 NULL,
-						 NULL,
+						 &types,
 						 description);
 		ret = ch_device_queue_process (priv->device_queue,
 					       CH_DEVICE_QUEUE_PROCESS_FLAGS_NONE,
@@ -1013,8 +1037,10 @@ ch_util_list_calibration (ChUtilPrivate *priv, gchar **values, GError **error)
 					       &error_local);
 		if (ret) {
 			if (description[0] != '\0') {
-				g_string_append_printf (string, "%i\t%s\n",
-							i, description);
+				tmp = ch_util_types_to_short_string (types);
+				g_string_append_printf (string, "%i\t%s [%s]\n",
+							i, description, tmp);
+				g_free (tmp);
 			}
 		} else {
 			g_debug ("ignoring error: %s", error_local->message);
@@ -1403,6 +1429,8 @@ ch_util_get_pcb_errata (ChUtilPrivate *priv, gchar **values, GError **error)
 	}
 	if ((pcb_errata & CH_PCB_ERRATA_SWAPPED_LEDS) > 0)
 		g_print ("Errata: swapped-leds\n");
+	if ((pcb_errata & CH_PCB_ERRATA_NO_WELCOME) > 0)
+		g_print ("Errata: no-welcome\n");
 out:
 	return ret;
 }
@@ -1429,6 +1457,10 @@ ch_util_set_pcb_errata (ChUtilPrivate *priv, gchar **values, GError **error)
 		g_print ("Errata: swapped-leds\n");
 		pcb_errata += CH_PCB_ERRATA_SWAPPED_LEDS;
 	}
+	if (g_strstr_len (values[0], -1, "no-welcome") != NULL) {
+		g_print ("Errata: no-welcome\n");
+		pcb_errata += CH_PCB_ERRATA_NO_WELCOME;
+	}
 
 	/* nothing known by this client version */
 	if (pcb_errata == CH_PCB_ERRATA_NONE)
@@ -1556,22 +1588,38 @@ static gboolean
 ch_util_set_dark_offsets_auto (ChUtilPrivate *priv, GError **error)
 {
 	gboolean ret;
+	gdouble post_scale_old = 0.0f;
 	CdColorRGB value_old;
+	CdColorRGB value_zero;
 	CdColorRGB value;
 
+	/* TRANSLATORS: wait for user to press the device into a desk... */
+	ret = ch_util_get_prompt (_("Ensure the ColorHug aperture is blocked"), TRUE);
+	if (!ret) {
+		g_set_error_literal (error, 1, 0,
+				     "user declined");
+		goto out;
+	}
+
 	/* set dark offsets */
-	cd_color_set_rgb (&value, 0.0f, 0.0f, 0.0f);
+	cd_color_set_rgb (&value_zero, 0.0f, 0.0f, 0.0f);
 
 	/* get from HW */
 	ch_device_queue_get_dark_offsets (priv->device_queue,
 					  priv->device,
 					  &value_old);
+	ch_device_queue_get_post_scale (priv->device_queue,
+					priv->device,
+					&post_scale_old);
 	ch_device_queue_set_dark_offsets (priv->device_queue,
 					  priv->device,
-					  &value);
+					  &value_zero);
 	ch_device_queue_set_integral_time (priv->device_queue,
 					   priv->device,
 					   CH_INTEGRAL_TIME_VALUE_MAX);
+	ch_device_queue_set_post_scale (priv->device_queue,
+					priv->device,
+					1);
 	ch_device_queue_set_multiplier (priv->device_queue,
 					priv->device,
 					CH_FREQ_SCALE_100);
@@ -1594,6 +1642,9 @@ ch_util_set_dark_offsets_auto (ChUtilPrivate *priv, GError **error)
 		ch_device_queue_set_dark_offsets (priv->device_queue,
 						  priv->device,
 						  &value_old);
+		ch_device_queue_set_post_scale (priv->device_queue,
+						priv->device,
+						post_scale_old);
 		ret = ch_device_queue_process (priv->device_queue,
 					       CH_DEVICE_QUEUE_PROCESS_FLAGS_NONE,
 					       NULL,
@@ -1609,6 +1660,9 @@ ch_util_set_dark_offsets_auto (ChUtilPrivate *priv, GError **error)
 	ch_device_queue_set_dark_offsets (priv->device_queue,
 					  priv->device,
 					  &value);
+	ch_device_queue_set_post_scale (priv->device_queue,
+					priv->device,
+					post_scale_old);
 	ch_device_queue_write_eeprom (priv->device_queue,
 				      priv->device,
 				      CH_WRITE_EEPROM_MAGIC);
